Rename wrap backend tex/rt methods on GrProxyProvider

This makes them more consistent with similar methods on GrResourceProvider.

Change-Id: Ice7e5dbe8100481781015b386445e9b7101bd75e
Reviewed-on: https://skia-review.googlesource.com/112821
Reviewed-by: Greg Daniel <egdaniel@google.com>
Commit-Queue: Brian Salomon <bsalomon@google.com>
diff --git a/tests/ProxyTest.cpp b/tests/ProxyTest.cpp
index f346f87..9d52281 100644
--- a/tests/ProxyTest.cpp
+++ b/tests/ProxyTest.cpp
@@ -207,15 +207,15 @@
                 }
 
                 // External on-screen render target.
                 // Tests createWrappedRenderTargetProxy with a GrBackendRenderTarget
                 {
                     GrGLFramebufferInfo fboInfo;
                     fboInfo.fFBOID = 0;
                     GrBackendRenderTarget backendRT(kWidthHeight, kWidthHeight, numSamples, 8,
                                                     config, fboInfo);
 
-                    sk_sp<GrSurfaceProxy> sProxy(proxyProvider->createWrappedRenderTargetProxy(
-                            backendRT, origin));
+                    sk_sp<GrSurfaceProxy> sProxy(
+                            proxyProvider->wrapBackendRenderTarget(backendRT, origin));
                     check_surface(reporter, sProxy.get(), origin,
                                   kWidthHeight, kWidthHeight,
                                   backendRT.testingOnly_getPixelConfig(), SkBudgeted::kNo);
@@ -224,15 +224,14 @@
                                        supportedNumSamples, SkBackingFit::kExact, 0);
                 }
 
                 // Tests createWrappedRenderTargetProxy with a GrBackendTexture
                 {
                     GrBackendTexture backendTex =
                             gpu->createTestingOnlyBackendTexture(nullptr, kWidthHeight,
                                                                  kWidthHeight, colorType, true,
                                                                  GrMipMapped::kNo);
-                    sk_sp<GrSurfaceProxy> sProxy =
-                            proxyProvider->createWrappedRenderTargetProxy(backendTex, origin,
-                                                                          supportedNumSamples);
+                    sk_sp<GrSurfaceProxy> sProxy = proxyProvider->wrapBackendTextureAsRenderTarget(
+                            backendTex, origin, supportedNumSamples);
                     if (!sProxy) {
                         gpu->deleteTestingOnlyBackendTexture(&backendTex);
                         continue;  // This can fail on Mesa
@@ -249,16 +248,15 @@
                     gpu->deleteTestingOnlyBackendTexture(&backendTex);
                 }
 
                 // Tests createWrappedTextureProxy that is only renderable
                 {
                     GrBackendTexture backendTex =
                             gpu->createTestingOnlyBackendTexture(nullptr, kWidthHeight,
                                                                  kWidthHeight, colorType, true,
                                                                  GrMipMapped::kNo);
 
-                    sk_sp<GrSurfaceProxy> sProxy =
-                            proxyProvider->createWrappedTextureProxy(backendTex, origin,
-                                                                     supportedNumSamples);
+                    sk_sp<GrSurfaceProxy> sProxy = proxyProvider->wrapRenderableBackendTexture(
+                            backendTex, origin, supportedNumSamples);
                     if (!sProxy) {
                         gpu->deleteTestingOnlyBackendTexture(&backendTex);
                         continue;  // This can fail on Mesa
@@ -275,7 +273,7 @@
                     gpu->deleteTestingOnlyBackendTexture(&backendTex);
                 }
 
                 // Tests createWrappedTextureProxy that is only textureable
                 {
                     // Internal offscreen texture
                     GrBackendTexture backendTex =
@@ -283,10 +281,8 @@
                                                                  kWidthHeight, colorType, false,
                                                                  GrMipMapped::kNo);
 
-                    sk_sp<GrSurfaceProxy> sProxy =
-                            proxyProvider->createWrappedTextureProxy(backendTex, origin,
-                                                                     kBorrow_GrWrapOwnership,
-                                                                     nullptr, nullptr);
+                    sk_sp<GrSurfaceProxy> sProxy = proxyProvider->wrapBackendTexture(
+                            backendTex, origin, kBorrow_GrWrapOwnership, nullptr, nullptr);
                     if (!sProxy) {
                         gpu->deleteTestingOnlyBackendTexture(&backendTex);
                         continue;
@@ -207,15 +207,15 @@
 
                 // External on-screen render target.
-                // Tests createWrappedRenderTargetProxy with a GrBackendRenderTarget
+                // Tests wrapBackendRenderTarget with a GrBackendRenderTarget
                 {
                     GrGLFramebufferInfo fboInfo;
@@ -224,15 +224,14 @@
                 }
 
-                // Tests createWrappedRenderTargetProxy with a GrBackendTexture
+                // Tests wrapBackendRenderTarget with a GrBackendTexture
                 {
                     GrBackendTexture backendTex =
@@ -249,16 +248,15 @@
                 }
 
-                // Tests createWrappedTextureProxy that is only renderable
+                // Tests wrapBackendTexture that is only renderable
                 {
                     GrBackendTexture backendTex =
@@ -275,7 +273,7 @@
                 }
 
-                // Tests createWrappedTextureProxy that is only textureable
+                // Tests wrapBackendTexture that is only textureable
                 {
                     // Internal offscreen texture